Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1771)

Unified Diff: content/renderer/web_intents_host.h

Issue 8934011: Rename IntentsHost -> WebIntentsDispatcher and IntentsDispatcher -> WebIntentsHost. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge to head Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/render_view_impl.cc ('k') | content/renderer/web_intents_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/web_intents_host.h
diff --git a/content/renderer/intents_dispatcher.h b/content/renderer/web_intents_host.h
similarity index 82%
rename from content/renderer/intents_dispatcher.h
rename to content/renderer/web_intents_host.h
index 2ebc324e4722672b3dae18aec8d31549eddd2498..4567dcdcbf70ab0e7f4bf6d99abc2be183049b04 100644
--- a/content/renderer/intents_dispatcher.h
+++ b/content/renderer/web_intents_host.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_RENDERER_INTENTS_DISPATCHER_H_
-#define CONTENT_RENDERER_INTENTS_DISPATCHER_H_
+#ifndef CONTENT_RENDERER_WEB_INTENTS_HOST_H_
+#define CONTENT_RENDERER_WEB_INTENTS_HOST_H_
#pragma once
#include "base/memory/scoped_ptr.h"
@@ -22,14 +22,14 @@ namespace webkit_glue {
struct WebIntentData;
}
// IntentsDispatcher is a delegate for Web Intents messages. It is the
// renderer-side handler for IPC messages delivering the intent payload data
// and preparing it for access by the service page.
-class IntentsDispatcher : public content::RenderViewObserver {
+class WebIntentsHost : public content::RenderViewObserver {
public:
// |render_view| must not be NULL.
- explicit IntentsDispatcher(RenderViewImpl* render_view);
- virtual ~IntentsDispatcher();
+ explicit WebIntentsHost(RenderViewImpl* render_view);
+ virtual ~WebIntentsHost();
// Called by the bound intent object to register the result from the service
// page.
@@ -63,7 +63,7 @@ class IntentsDispatcher : public content::RenderViewObserver {
// injected into the Javascript context.
scoped_ptr<BoundDeliveredIntent> delivered_intent_;
- DISALLOW_COPY_AND_ASSIGN(IntentsDispatcher);
+ DISALLOW_COPY_AND_ASSIGN(WebIntentsHost);
};
-#endif // CONTENT_RENDERER_INTENTS_DISPATCHER_H_
+#endif // CONTENT_RENDERER_WEB_INTENTS_HOST_H_
« no previous file with comments | « content/renderer/render_view_impl.cc ('k') | content/renderer/web_intents_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -22,14 +22,14 @@ namespace webkit_glue {
struct WebIntentData;
}
-// IntentsDispatcher is a delegate for Web Intents messages. It is the
+// WebIntentsHost is a delegate for Web Intents messages. It is the
// renderer-side handler for IPC messages delivering the intent payload data
// and preparing it for access by the service page.
This is Rietveld 408576698